==> sigutils-2.2.7.tar.gz: sigutils-2.2.7/SigUtils/calcDigito.py <==
#- coding: utf-8
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "2.00"
__DataAlteracao__ = "13/03/2014"

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(
                     'modulo10.py\t\tVersao:' + __Versao__ + '\tData:' + __DataAlteracao__) + '\tCalculo de digito no modulo 10'
        else:
            print('\n\nmodulo10.py - Calculo de digito no modulo 10 \n'
                  + 'Versao: ' + __Versao__ + '\n'
                  + 'Data: ' + __DataAlteracao__ + '\n')
    except:
        print('\n\nmodulo10.py - Calculo de digito no modulo 10 \n'
              + 'Versao: ' + __Versao__ + '\n'
              + 'Data: ' + __DataAlteracao__ + '\n')

from SigUtils.formatastring import *


def baseModulo(Codigo, Multiplicador, Base=11, subResto='S', somaDigitos='N'):
    """Funcao para calculo geral de digito de controle
           - Codigo = Numero sobre o qual será calculado o digito
           - Multiplicador = multiplicador a ser usado ex.: 98765432 ou 12 ou 765432, etc
           - subResto, indica se o resto da divisão será subtraido da base
           - somaDigitos indica se depois de usar o multiplicador, os digitos deste resultado devem ser somados
       Retorna o digito ou -1 se houver problema"""
    try:
        Codigo = str(Codigo)
        Multiplicador = str(Multiplicador)
        Base = int(Base)
        _tamCodigo = len(Codigo)
        _tamMultiplicador = len(Multiplicador)
        if _tamMultiplicador > _tamCodigo:
            Multiplicador = Multiplicador[(_tamCodigo * -1):]
        elif _tamMultiplicador < _tamCodigo:
            Multiplicador = Multiplicador * (int(_tamCodigo / _tamMultiplicador) + 1)
            Multiplicador = Multiplicador[(_tamCodigo * -1):]
        resultado = 0
        for x in range(_tamCodigo):
            if somaDigitos == 'N':
                resultado += (int(Codigo[x]) * int(Multiplicador[x]))
            else:
                iTemporario = (int(Codigo[x]) * int(Multiplicador[x]))
                sTemporario = formataString(str(iTemporario), 2, "0", alinhamento="E", usaTrim="S", forcado='N')
                resultado = resultado + int(sTemporario[0]) + int(sTemporario[1])
        if subResto == 'S':
            digito = Base - (resultado % Base)
        else:
            digito = resultado % Base
        return str(digito)
    except:
        return '-1'


def modulo10(Codigo):
    """Funcao para calculo do modulo 10
      Recebe um codigo, e retorna o digito de controle"""
    try:
        digito = baseModulo(Codigo, '12', 10)
        if digito == '-1':
            return digito
        if digito == '10':
            digito = 0
        return str(digito)
    except:
        return '-1'

def ean(Codigo):
    """Funcao para calculo do digito de controle de codigos ean
      Recebe um codigo, e retorna o digito de controle"""
    try:
        Codigo = str(Codigo)
        if len(Codigo) > 13:
            Codigo = Codigo[0:13]
        else:
            Codigo = formataString(Codigo, 13, "0", alinhamento="E", usaTrim="S", forcado='N')
        t2 = int(Codigo[0:1]) + int(Codigo[2:3]) + int(Codigo[4:5]) + int(Codigo[6:7]) + int(
            Codigo[8:9]) + int(Codigo[10:11]) + int(Codigo[12:13])
        t1 = int(Codigo[1:2]) + int(Codigo[3:4]) + int(Codigo[5:6]) + int(Codigo[7:8]) + int(
            Codigo[9:10]) + int(Codigo[11:12])
        t2 = (t2 * 3) + t1
        t3 = (((t2 / 10) + 1) * 10) - t2
        if t3 == 10:
            t3 = 0
        return t3
    except:
        return '-1'

def codigo_barra_bancario(codigo_barras):
    """
    Função para verificar o codigo de barras, e retornar no formato escaneado ou digitado
    @param codigo_barras: Codigo de barras a ser validado e formatado
    @return: lista com tres valores:
         1 - True ou False informando se o codigo de barras está correto
         2 - o codigo de barras no formato escaneado
         3 - o codigo de barras no formato digitado
    """
    def __codigo_de_boleto():
        res0 = False
        formato_escaneado = formato_digitado = ''
        if len(codigo_barras) == 44:
            formato_escaneado = codigo_barras
            _cb = codigo_barras[:4] + codigo_barras[5:]
            dv = baseModulo(_cb, '98765432')
            if dv in ('0', '1', '10', '11'):
                dv = '1'
            if dv == codigo_barras[4:5]:
                res0 = True
                x1 = _cb[:4]+_cb[18:23]
                x2 = _cb[23:33]
                x3 = _cb[33:43]
                x4 = _cb[4:18]
                dv1 = baseModulo(x1, '12', 10, 'S', 'S')
                if dv1 =='10':
                    dv1 = '0'
                dv2 = baseModulo(x2, '12', 10, 'S', 'S')
                if dv2 =='10':
                    dv2 = '0'
                dv3 = baseModulo(x3, '12', 10, 'S', 'S')
                if dv3 =='10':
                    dv3 = '0'
                formato_digitado = x1 + dv1 + x2 + dv2 + x3 + dv3 + dv + x4
        if len(codigo_barras) == 47:
            formato_digitado = codigo_barras
            _cb = codigo_barras
            x1 = _cb[:9]
            dv1 = _cb[9:10]
            x2 = _cb[10:20]
            dv2 = _cb[20:21]
            x3 = _cb[21:31]
            dv3 = _cb[31:32]
            _dv = _cb[32:33]
            x4 = _cb[33:]
            _d1 = baseModulo(x1, '12', 10, 'S', 'S')
            if _d1 =='10':
                _d1 = '0'
            _d2 = baseModulo(x2, '12', 10, 'S', 'S')
            if _d2 =='10':
                _d2 = '0'
            _d3 = baseModulo(x3, '12', 10, 'S', 'S')
            if _d3 =='10':
                _d3 = '0'
            if _d1 == dv1 and _d2 == dv2 and _d3 == dv3:
                x = _cb[:4] + _cb[33:] + _cb[4:9] + _cb[10:20] + _cb[21:31]
                _d = baseModulo(x, '98765432')
                if _d in ('0', '1', '10', '11'):
                    _d = '1'
                if _d == _dv:
                    res0 = True
                    formato_escaneado = x[:4] + _d + x[4:]
        return res0, formato_escaneado, formato_digitado
    def __codigo_de_concessionarias():
        res0 = False
        formato_escaneado = formato_digitado = ''
        if len(codigo_barras) == 44:
            formato_escaneado = codigo_barras
            _cb = codigo_barras[:3] + codigo_barras[4:]
            dv = baseModulo(_cb, '12', 10, 'S', 'S')
            if dv == '10':
                dv == '0'
            if dv == codigo_barras[3:4]:
                res0 = True
                x1 = codigo_barras[:11]
                x2 = codigo_barras[11:22]
                x3 = codigo_barras[22:33]
                x4 = codigo_barras[33:]
                _dv1 = baseModulo(x1, '12', 10, 'S', 'S')
                if _dv1 == '10':
                    _dv1 = '0'
                _dv2 = baseModulo(x2, '12', 10, 'S', 'S')
                if _dv2 == '10':
                    _dv2 = '0'
                _dv3 = baseModulo(x3, '12', 10, 'S', 'S')
                if _dv3 == '10':
                    _dv3 = '0'
                _dv4 = baseModulo(x4, '12', 10, 'S', 'S')
                if _dv4 == '10':
                    _dv4 = '0'
                formato_digitado = x1 + _dv1 + x2 + _dv2 + x3 + _dv3 + x4 + _dv4

        if len(codigo_barras) == 48:
            formato_digitado = codigo_barras
            _cb = codigo_barras
            x1 = _cb[:11]
            dv1 = _cb[11:12]
            x2 = _cb[12:23]
            dv2 = _cb[23:24]
            x3 = _cb[24:35]
            dv3 = _cb[35:36]
            x4 = _cb[36:47]
            dv4 = _cb[47:]
            _dv1 = baseModulo(x1, '12', 10, 'S', 'S')
            if _dv1 == '10':
                _dv1 = '0'
            _dv2 = baseModulo(x2, '12', 10, 'S', 'S')
            if _dv2 == '10':
                _dv2 = '0'
            _dv3 = baseModulo(x3, '12', 10, 'S', 'S')
            if _dv3 == '10':
                _dv3 = '0'
            _dv4 = baseModulo(x4, '12', 10, 'S', 'S')
            if _dv4 == '10':
                _dv4 = '0'
            if _dv1 == dv1 and _dv2 == dv2 and _dv3 == dv3 and _dv4 == dv4:
                res0 = True
                formato_escaneado = x1 + x2 + x3 + x4
        return res0, formato_escaneado, formato_digitado
    res0 = False
    formato_escaneado = formato_digitado = ''
    if codigo_barras:
        if codigo_barras[:1] =='8':
            res0, formato_escaneado, formato_digitado = __codigo_de_concessionarias()
        else:
            res0, formato_escaneado, formato_digitado = __codigo_de_boleto()
    return res0, formato_escaneado, formato_digitado

==> sigutils-2.4.7.tar.gz: sigutils-2.4.7/SigUtils/calcDigito.py <==
#- coding: utf-8
from SigUtils.formatastring import *


def baseModulo(Codigo, Multiplicador, Base=11, subResto='S', somaDigitos='N'):
    """Funcao para calculo geral de digito de controle
           - Codigo = Numero sobre o qual será calculado o digito
           - Multiplicador = multiplicador a ser usado ex.: 98765432 ou 12 ou 765432, etc
           - subResto, indica se o resto da divisão será subtraido da base
           - somaDigitos indica se depois de usar o multiplicador, os digitos deste resultado devem ser somados
       Retorna o digito ou -1 se houver problema"""
    try:
        Codigo = str(Codigo)
        Multiplicador = str(Multiplicador)
        Base = int(Base)
        _tamCodigo = len(Codigo)
        _tamMultiplicador = len(Multiplicador)
        if _tamMultiplicador > _tamCodigo:
            Multiplicador = Multiplicador[(_tamCodigo * -1):]
        elif _tamMultiplicador < _tamCodigo:
            Multiplicador = Multiplicador * (int(_tamCodigo / _tamMultiplicador) + 1)
            Multiplicador = Multiplicador[(_tamCodigo * -1):]
        resultado = 0
        for x in range(_tamCodigo):
            if somaDigitos == 'N':
                resultado += (int(Codigo[x]) * int(Multiplicador[x]))
            else:
                iTemporario = (int(Codigo[x]) * int(Multiplicador[x]))
                sTemporario = formataString(str(iTemporario), 2, "0", alinhamento="E", usaTrim="S", forcado='N')
                resultado = resultado + int(sTemporario[0]) + int(sTemporario[1])
        if subResto == 'S':
            digito = Base - (resultado % Base)
        else:
            digito = resultado % Base
        return str(digito)
    except:
        return '-1'


def modulo10(Codigo):
    """Funcao para calculo do modulo 10
      Recebe um codigo, e retorna o digito de controle"""
    try:
        digito = baseModulo(Codigo, '12', 10)
        if digito == '-1':
            return digito
        if digito == '10':
            digito = 0
        return str(digito)
    except:
        return '-1'

def ean(Codigo):
    """Funcao para calculo do digito de controle de codigos ean
      Recebe um codigo, e retorna o digito de controle"""
    try:
        Codigo = str(Codigo)
        if len(Codigo) > 13:
            Codigo = Codigo[0:13]
        else:
            Codigo = formataString(Codigo, 13, "0", alinhamento="E", usaTrim="S", forcado='N')
        t2 = int(Codigo[0:1]) + int(Codigo[2:3]) + int(Codigo[4:5]) + int(Codigo[6:7]) + int(
            Codigo[8:9]) + int(Codigo[10:11]) + int(Codigo[12:13])
        t1 = int(Codigo[1:2]) + int(Codigo[3:4]) + int(Codigo[5:6]) + int(Codigo[7:8]) + int(
            Codigo[9:10]) + int(Codigo[11:12])
        t2 = (t2 * 3) + t1
        t3 = (((t2 / 10) + 1) * 10) - t2
        if t3 == 10:
            t3 = 0
        return t3
    except:
        return '-1'

def codigo_barra_bancario(codigo_barras):
    """
    Função para verificar o codigo de barras, e retornar no formato escaneado ou digitado
    @param codigo_barras: Codigo de barras a ser validado e formatado
    @return: lista com tres valores:
         1 - True ou False informando se o codigo de barras está correto
         2 - o codigo de barras no formato escaneado
         3 - o codigo de barras no formato digitado
    """
    def __codigo_de_boleto():
        res0 = False
        formato_escaneado = formato_digitado = ''
        if len(codigo_barras) == 44:
            formato_escaneado = codigo_barras
            _cb = codigo_barras[:4] + codigo_barras[5:]
            dv = baseModulo(_cb, '98765432')
            if dv in ('0', '1', '10', '11'):
                dv = '1'
            if dv == codigo_barras[4:5]:
                res0 = True
                x1 = _cb[:4]+_cb[18:23]
                x2 = _cb[23:33]
                x3 = _cb[33:43]
                x4 = _cb[4:18]
                dv1 = baseModulo(x1, '12', 10, 'S', 'S')
                if dv1 =='10':
                    dv1 = '0'
                dv2 = baseModulo(x2, '12', 10, 'S', 'S')
                if dv2 =='10':
                    dv2 = '0'
                dv3 = baseModulo(x3, '12', 10, 'S', 'S')
                if dv3 =='10':
                    dv3 = '0'
                formato_digitado = x1 + dv1 + x2 + dv2 + x3 + dv3 + dv + x4
        if len(codigo_barras) == 47:
            formato_digitado = codigo_barras
            _cb = codigo_barras
            x1 = _cb[:9]
            dv1 = _cb[9:10]
            x2 = _cb[10:20]
            dv2 = _cb[20:21]
            x3 = _cb[21:31]
            dv3 = _cb[31:32]
            _dv = _cb[32:33]
            x4 = _cb[33:]
            _d1 = baseModulo(x1, '12', 10, 'S', 'S')
            if _d1 =='10':
                _d1 = '0'
            _d2 = baseModulo(x2, '12', 10, 'S', 'S')
            if _d2 =='10':
                _d2 = '0'
            _d3 = baseModulo(x3, '12', 10, 'S', 'S')
            if _d3 =='10':
                _d3 = '0'
            if _d1 == dv1 and _d2 == dv2 and _d3 == dv3:
                x = _cb[:4] + _cb[33:] + _cb[4:9] + _cb[10:20] + _cb[21:31]
                _d = baseModulo(x, '98765432')
                if _d in ('0', '1', '10', '11'):
                    _d = '1'
                if _d == _dv:
                    res0 = True
                    formato_escaneado = x[:4] + _d + x[4:]
        return res0, formato_escaneado, formato_digitado
    def __codigo_de_concessionarias():
        res0 = False
        formato_escaneado = formato_digitado = ''
        if len(codigo_barras) == 44:
            formato_escaneado = codigo_barras
            _cb = codigo_barras[:3] + codigo_barras[4:]
            dv = baseModulo(_cb, '4329876543298765432987654329876543298765432', 11, 'S', 'N')
            if dv == '11':
                dv = '0'
            if dv == '10':
                dv = '0'
            if dv == codigo_barras[3:4]:
                res0 = True
                x1 = codigo_barras[:11]
                x2 = codigo_barras[11:22]
                x3 = codigo_barras[22:33]
                x4 = codigo_barras[33:]
                _dv1 = baseModulo(x1, '43298765432', 11, 'S', 'N')
                if _dv1 == '11':
                    _dv1 = '0'
                if _dv1 == '10':
                    _dv1 = '0'
                _dv2 = baseModulo(x2, '43298765432', 11, 'S', 'N')
                if _dv2 == '11':
                    _dv2 = '0'
                if _dv2 == '10':
                    _dv2 = '0'
                _dv3 = baseModulo(x3, '43298765432', 11, 'S', 'N')
                if _dv3 == '11':
                    _dv3 = '0'
                if _dv3 == '10':
                    _dv3 = '0'
                _dv4 = baseModulo(x4, '43298765432', 11, 'S', 'N')
                if _dv4 == '11':
                    _dv4 = '0'
                if _dv4 == '10':
                    _dv4 = '0'
                formato_digitado = x1 + _dv1 + x2 + _dv2 + x3 + _dv3 + x4 + _dv4

        if len(codigo_barras) == 48:
            formato_digitado = codigo_barras
            _cb = codigo_barras
            x1 = _cb[:11]
            dv1 = _cb[11:12]
            x2 = _cb[12:23]
            dv2 = _cb[23:24]
            x3 = _cb[24:35]
            dv3 = _cb[35:36]
            x4 = _cb[36:47]
            dv4 = _cb[47:]
            _dv1 = baseModulo(x1, '43298765432', 11, 'S', 'N')
            if _dv1 == '11':
                _dv1 = '0'
            if _dv1 == '10':
                _dv1 = '0'
            _dv2 = baseModulo(x2, '43298765432', 11, 'S', 'N')
            if _dv2 == '11':
                _dv2 = '0'
            if _dv2 == '10':
                _dv2 = '0'
            _dv3 = baseModulo(x3, '43298765432', 11, 'S', 'N')
            if _dv3 == '11':
                _dv3 = '0'
            if _dv3 == '10':
                _dv3 = '0'
            _dv4 = baseModulo(x4, '43298765432', 11, 'S', 'N')
            if _dv4 == '11':
                _dv4 = '0'
            if _dv4 == '10':
                _dv4 = '0'
            if _dv1 == dv1 and _dv2 == dv2 and _dv3 == dv3 and _dv4 == dv4:
                res0 = True
                formato_escaneado = x1 + x2 + x3 + x4
        return res0, formato_escaneado, formato_digitado
    res0 = False
    formato_escaneado = formato_digitado = ''
    if codigo_barras:
        if codigo_barras[:1] == '8':
            res0, formato_escaneado, formato_digitado = __codigo_de_concessionarias()
        else:
            res0, formato_escaneado, formato_digitado = __codigo_de_boleto()
    return res0, formato_escaneado, formato_digitado
